Fer una avaluació de riscos amb OiRA | OiRA

Temes

# Fer una avaluació de riscos amb OiRA

## Iniciar una nova sessió

Per iniciar una nova avaluació de riscos, cliqueu l’enllaç «Inicieu una nova sessió».

## Obertura d’una avaluació de riscos

Un cop hàgiu iniciat una avaluació de riscos, podreu recuperar-la en qualsevol moment mitjançant el tauler de control «Les meves avaluacions de riscos». Des d’aquest mateix lloc, podreu iniciar una avaluació nova.

Tauler de control

## Navegueu per una avaluació de riscos

Cada avaluació de riscos consta de diversos passos. Es poden veure en el menú principal, a la banda esquerra:

- Preparació
- Participació
- Identificació + Avaluació
- Pla d’acció
- Informe
- Grau d’emplenament

En funció de les decisions que adopten els socis o els desenvolupadors de les eines, l’arquitectura de l’eina específica pot variar. En algunes, la fase d’identificació i avaluació de riscos també inclou directament el pla d’acció. En aquest cas, el menú de l’esquerra conté els punts següents:

- Preparació
- Participació
- Avaluació
- Informe
- Grau d’emplenament

## Preparació

La preparació és on inicieu automàticament cada sessió o eina. En aquesta pàgina s’assigna un nom a l’avaluació de riscos a fi d’ajudar-vos posteriorment a distingir les diferents avaluacions de riscos que hàgiu realitzat amb l’eina.

L’enllaç «Aprengueu més sobre aquesta eina…» mostra informació addicional, específicament sobre l’eina seleccionada i les parts que intervenen en el desenvolupament.

Després de clicar el botó «Inicieu», és possible que se us formulin algunes preguntes addicionals, depenent de l’eina que utilitzeu. Aquesta pàgina de preparació amb «preguntes de perfil» només apareix en les eines que ofereixen aquesta opció. Aquí podeu:

- Seleccionar o ometre situacions en funció de si són aplicables a l’activitat de la vostra empresa. Trieu «Sí», si escau.
- Indicar les múltiples unitats de negoci, sucursals o botigues, etc. Els riscos relacionats es repetiran per a cada nom que hàgiu introduït.

La pantalla «Perfil» en el pas de preparació

El pas de preparació és molt important, ja que defineix amb precisió el tipus d’activitat i els riscos relacionats als quals ha de fer front la vostra empresa. Després de clicar «Guardeu i continueu», accedireu automàticament a la secció següent, «Participació».

Nota: Moltes eines no inclouen preguntes de perfil, ja que no utilitzen aquesta funció per dirigir l’eina. En aquest cas, aquesta pantalla salta automàticament.

## Participació

Aquest pas us recorda que és important que els treballadors hi participin i ofereix diferents possibilitats per garantir-ho. En aquesta pantalla us podeu descarregar o imprimir el contingut de l’avaluació de riscos per compartir-lo amb els treballadors. D’aquesta manera, s’assegura que aquests puguin contribuir a l’avaluació de la situació del seu lloc de treball.

## Identificació + Avaluació

En aquesta fase, haureu d’identificar els perills i els problemes de la vostra empresa.

Nota: Segons com el soci de l’OiRA hagi configurat l’eina, el pas «Pla d’acció» (vegeu més endavant) ja pot integrar-se en aquesta pantalla. En aquest cas, tot el pas es denomina «Avaluació» i els elements que es descriuen a continuació a l’apartat «Pla d’acció» apareixeran amb la identificació i l’avaluació de cada risc.

Identificació + Avaluació

A l’esquerra d’aquesta pàgina, a sota d’«Identificació + Avaluació» o «Avaluació», podeu veure tots els temes o mòduls que s’inclouen a l’eina. El tema que esteu veient en aquest moment apareix ressaltat.

Per a cada risc individual, heu de decidir si la declaració descrita d’un estat positiu és vàlida per a la vostra empresa:

- Sí: si responeu afirmativament en l’encapçalament amb un sí, no és necessari que feu res més, ja que heu avaluat que el risc no existeix.
- No: si responeu amb un no, vol dir que heu de prendre més mesures. En aquest cas, se us demanarà que decidiu mesures específiques.
- No procedeix: algunes declaracions de risc us ofereixen la possibilitat de seleccionar «No procedeix» en cas que el risc no sigui pertinent per a la vostra empresa o centre de treball.

Normalment, a sota de cada declaració a la qual heu de respondre, s’hi inclou informació addicional sobre el risc específic:

- Informació: una breu descripció, opcionalment amb imatges il·lustratives, a fi d’oferir més detalls sobre el risc.
- Recursos: informació addicional sobre el risc, com ara referències legals i polítiques. A vegades, en aquest apartat també podeu trobar documents adjunts que us ajudaran a ampliar la informació.
- Comentaris: aquí podeu incloure comentaris, que apareixeran en el vostre informe al final de l’avaluació.

Després de respondre a la declaració de riscos, en continuar, el menú de l’esquerra s’actualitzarà amb un símbol en color, que indicarà el següent:

- Heu respost afirmativament (marca en verd).
- Heu respost negativament (creu vermella).
- Heu posposat (signe d’interrogació en groc).
- En el cas de les preguntes sense resposta, es manté el símbol gris.

### Avaluació

En aquest pas, haureu d’avaluar la prioritat d’un risc que hàgiu identificat.

Avalueu un risc

Nota: En alguna eina OiRA pot ser que no es mostri l’avaluació. Això depèn de com el soci l’ha configurada.

Si heu identificat un risc com a existent (quan es mostri la creu vermella), apareixerà la secció d’avaluació. En funció del mètode d’avaluació que s’ha establert per a cada risc, caldrà:

- Estimar directament la prioritat: alta, mitjana o baixa.

Establiu la prioritat d’un risc

o bé

- Respondre a tres preguntes sobre la freqüència, la gravetat i la probabilitat del risc, de tal manera que la prioritat pugui calcular-se d’acord amb les vostres respostes.

Establiu variables per a un risc

### Riscos prioritaris

Alguns riscos són considerats d’alta importància pel soci o el desenvolupador que va crear l’eina específica. No és necessari calcular aquests «riscos prioritaris», ja que la prioritat s’estableix automàticament com a «alta».

Riscos prioritaris

### Riscos personalitzats

Un cop hàgiu acabat de respondre tots els temes de riscos en «Identificació + Avaluació» o «Avaluació», accedireu al tema opcional «Riscos afegits». En aquest cas, el botó «Afegiu un altre risc» us permetrà crear les vostres entrades.

En cas que observeu que determinats riscos detectats en el vostre lloc de treball o en la vostra empresa no apareixen a l’eina, haureu d’afegir-hi els riscos personalitzats; podreu definir o formular íntegrament aquests riscos.

Riscos personalitzats

Un «risc personalitzat» funciona de manera molt similar als riscos que ofereix OiRA, però, evidentment, és necessari que redacteu el vostre text: una declaració breu en què es descrigui la situació problemàtica (declaració positiva) i, opcionalment, una descripció més llarga i detallada. També hi podeu inserir una imatge per il·lustrar una situació determinada.

De la mateixa manera que passa amb els riscos previstos, heu de declarar si hi ha risc o no. Per tant, tindreu la possibilitat de descartar els riscos personalitzats un cop els hàgiu abordat amb èxit, tot i que sempre els podreu conservar a la vostra avaluació de riscos a l’efecte de tenir la documentació.

Podeu afegir-hi tants riscos personalitzats com us sigui necessari.

Afegiu un risc personalitzat

## Pla d’acció

En aquest pas, heu de decidir les mesures que voleu aplicar per eliminar o reduir els riscos que heu identificat anteriorment.

Nota: Com s’ha esmentat abans, el pla d’acció es presenta com un pas separat ressaltat en el menú de l’esquerra o com un pas a cada risc identificat. En aquest darrer cas, el pas en el menú de l’esquerra s’anomena «Avaluació» i inclou tant les declaracions de risc que s’han de respondre com les solucions que s’han d’escollir.

La versió que es facilita depèn de les decisions que prengui el soci o el desenvolupador nacional d’OiRA.

### Pla d’acció integrat

Pla d’acció integrat

Si responeu una pregunta amb un no, es desplegarà el mòdul del pla d’acció, amb el títol «Mesures».

Podeu seleccionar o definir les vostres mesures a partir de la llista de mesures proposades.

### Pla d’acció separat

Quan el pla d’acció és un pas separat, es podrà accedir mitjançant el panell de navegació de l’esquerra.

Cliqueu el botó «Creeu un pla d’acció» per començar el vostre pla.

En el pas del pla d’acció, el menú principal de l’esquerra només mostra els riscos marcats per a accions posteriors, atès que la resta de riscos es van marcar com a no existents.

Per a cada risc en què hàgiu respost amb un no durant el procés d’avaluació i per als riscos prioritaris (independentment que s’hagin respost positivament o negativament), haureu de definir mesures.

Pla d'acció

Podeu seleccionar entre una llista de mesures proposades pel sistema o definir les vostres.

#### Afegir la vostra mesura

Afegiu la vostra mesura

Premeu el botó «Afegiu una altra mesura» per començar a definir una mesura preventiva. Completeu la informació següent:

- Descriviu l’enfocament general que s’haurà d’adoptar per eliminar o reduir el risc.
- Indiqueu opcionalment el nivell d’experiència o els requisits necessaris (per exemple, podeu afegir-hi si cal formació específica o experiència externa per abordar aquest risc).
- Introduïu informació sobre qui és la persona responsable de l’aplicació.
- Definiu un pressupost, si escau.
- De manera opcional, establiu dates per començar a aplicar la mesura i quan teniu previst que finalitzi.

Podeu afegir-hi tantes mesures com sigui necessari.

#### Afegiu una mesura preestablerta

En funció de com hagi configurat l’eina el soci o el desenvolupador corresponent, es disposaran de mesures preestablertes per als riscos individuals. Per triar una o més mesures preestablertes, cliqueu «Seleccioneu mesures preestablertes».

S’obre un menú emergent que mostra totes les mesures proposades. Feu clic al botó «Afegiu» que apareix al darrere de les mesures que voleu utilitzar.

Les mesures preestablertes s’inclouen a continuació en el vostre pla d’acció. La descripció del que s’ha de fer és fixa, però haureu d’emplenar els altres camps (responsabilitat, pressupost i dates).

Afegiu una mesura preestablerta.

Les mesures preestablertes i les mesures que heu definit es poden eliminar en qualsevol moment.

## Informe

Després de finalitzar el pla d’acció, podeu descarregar un informe.

Si desitgeu deixar un comentari perquè s’inclogui a l’informe, escriviu el text en aquest camp i guardeu-lo.

Comenteu l'informe

Consulteu aquí per accedir a la informació addicional sobre els diferents informes i per saber com utilitzar-los.

## Grau d’emplenament

El petit gràfic circular que hi ha en el menú de l’esquerra mostra el progrés general que s’ha fet a l’eina.

La secció de grau d’emplenament ofereix una visió general del nombre de riscos que heu identificat, quants n’heu abordat mitjançant la decisió de mesures i quants riscos o declaracions no heu respost encara.

Pàgina de grau d’emplenament.

En accedir a la pàgina de grau d’emplenament, podreu veure quant heu avançat en cada mòdul. Aquesta informació us pot ajudar a saber on cal seguir avaluant riscos o proporcionant mesures per als riscos que heu identificat.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More